@@ -82,23 +82,4 @@ class BehaviourInterface:
         else:
             raise RequirementCrashed(
                 f"the dispatching requirement crashed: {cube}"
-            )
-    
-    def find_route(self, route: str) -> Any:
-        start_offset = self._index + int(bool(self._index))
-
-        for self.require_contents[-1]._index, behaviour in enumerate(
-            itertools.islice(self.behaviour_generator(), start_offset, None, None),
-            start=start_offset
-        ):
-            result = behaviour.route(route)
-    
-            if result is None:
-                continue
-
-            self.require_contents[-1]._index = 0
-            return result
-        else:
-            raise RequirementCrashed(
-                f"the dispatching requirement crashed: {route}"
             )
\ No newline at end of file
